package com.zbf.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.zbf.system.domain.TBasePallet;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 托盘Mapper接口
 *
 * @author sunits
 * @date 2024-06-16
 */
public interface TBasePalletMapper extends BaseMapper<TBasePallet> //修改
{
    /**
     * 查询托盘
     *
     * @param id 托盘主键
     * @return 托盘
     */
    public TBasePallet selectTBasePalletById(Long id);

    /**
     * 查询托盘列表
     *
     * @param tBasePallet 托盘
     * @return 托盘集合
     */
    public List<TBasePallet> selectTBasePalletList(TBasePallet tBasePallet);

    /**
     * 新增托盘
     *
     * @param tBasePallet 托盘
     * @return 结果
     */
    public int insertTBasePallet(TBasePallet tBasePallet);

    /**
     * 修改托盘
     *
     * @param tBasePallet 托盘
     * @return 结果
     */
    public int updateTBasePallet(TBasePallet tBasePallet);

    /**
     * 删除托盘
     *
     * @param id 托盘主键
     * @return 结果
     */
    public int deleteTBasePalletById(Long id);

    /**
     * 批量删除托盘
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTBasePalletByIds(Long[] ids);

    /**
     * 批量启用托盘
     *
     * @param ids 需要启用的数据主键集合
     * @return 结果
     */
    public int enableTBasePalletByIds(Long[] ids);

    /**
     * 批量禁用托盘
     *
     * @param ids 需要禁用的数据主键集合
     * @return 结果
     */
    public int disabledTBasePalletByIds(Long[] ids);

    int updateEcp(TBasePallet tBasePallet);

    void updateLockStatus(TBasePallet tBasePallet);
    @Select("update t_base_pallet set status = '1' where pallet_id In(SELECT DISTINCT ctl FROM t_mi_stock WHERE ctl IS NOT NULL)")
    void updatePallet();
}
